##  Mapping Fields
The integration allows you to map the fields of your fact sheets from SAP LeanIX into attributes on your assets in Collibra. To learn more about supported field types and how they are mapped, see [Supported Field Types for Fact Sheet Mapping](https://help.sap.com/docs/leanix/ea/supported-field-types-for-fact-sheet-mapping?locale=en-US&state=PRODUCTION&version=CLOUD "This document lists the supported field types from SAP LeanIX that can be mapped to Collibra attribute types."). If you choose a single or multi select attribute on both ends, you can further specify how values are mapped.
To configure field mapping, next to Field Mapping, click Add, then select values in the From and To fields. To add more fields, repeat these steps.
When choosing attribute types for Collibra, the options are categorized based on their scopes or assignments. Attribute types with a default or global scope are grouped under Global, while other attribute types are categorized under their respective scopes, for example, "Data Privacy."
![Mapping Fields](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274a3c5e7a4410148988c3ae2188e92b_LowRes.png)
Mapping Fields
